=============
WaiverDB APIs
=============

WavierDB offers a HTTP REST API.


.. _rest-api:

REST API
========

.. autoflask:: waiverdb.app:create_app(config_obj='waiverdb.config.DevelopmentConfig')
    :undoc-static:
    :order: path
